## Help

- `?`: Display/Close help message.
- `q`: Quit.

### Navigation

- `j`: Move to next article.
- `k`: Move to previous article.

### Posts

- `o/enter`: Open link in browser and mark post as read.
- `x`: Mark post as read.
- `shift+a`: Mark all posts as read.
